from xgi.generators import classic, nonuniform, uniform
from xgi.generators.classic import *
from xgi.generators.nonuniform import *
from xgi.generators.uniform import *
